.. image:: ./_static/github-social-card.png
    :width: 800 px

.. include:: badges.rst

----

.. include:: explanation.rst

----


Documentation
=============

.. toctree::
    :maxdepth: 3
    :caption: Content

    install
    quickstart_unilateral
    api
    license


Index & search
--------------

*  :ref:`genindex`
*  :ref:`search`

----

.. include:: refs.rst
